View source: R/axialnntsmanifoldnewtonestimationgradientstopknownmu.R
| axialnntsmanifoldnewtonestimationgradientstopknownmu | R Documentation |
Computes the maximum likelihood estimates of the parameters of an axial symmetric NNTS distribution with known location angle, using a Newton algorithm on the hypersphere and considering a maximum number of iterations determined by a constraint in terms of the norm of the gradient
axialnntsmanifoldnewtonestimationgradientstopknownmu(data, muknown=0, M = 0, iter = 1000,
initialpoint = FALSE, cinitial,gradientstop=1e-10)
data |
Vector of axial angles in radians |
muknown |
Value of the known location angle |
M |
Number of components in the NNTS axial model |
iter |
Number of iterations |
initialpoint |
TRUE if an initial point for the optimization algorithm for the axial NNTS density will be used |
cinitial |
Vector of size M+1. The first element is real and the next M elements are complex (values for $c_0$ and $c_1, ...,c_M$). The sum of the squared moduli of the parameters must be equal to 1/pi. |
gradientstop |
The minimum value of the norm of the gradient to stop the Newton algorithm on the hypersphere |
A list with 13 elements:
cestimatesmuknown |
Matrix of (M+1)x2. The first column is the parameter numbers, and the second column is the c parameter's estimators of the NNTS axial model with known location angle |
muknown |
Known value of the location angle of the NNTS axial model |
loglikmuknown |
Optimum log-likelihood value for the NNTS axial model with known location angle |
AICmuknown |
Value of Akaike's Information Criterion for the NNTS axial model with known location angle |
BICmuknown |
Value of Bayesian Information Criterion for the NNTS axial model with known location angle |
gradnormerrormuknown |
Gradient error after the last iteration for the estimation of the parameters of the NNTS axial model with known location angle |
cestimatesmuunknown |
Matrix of (M+1)x2. The first column is the parameter numbers, and the second column is the c parameter's estimators of the NNTS axial model with unknown location angle |
loglikmuunknown |
Optimum log-likelihood value for the general NNTS axial model with unknown location angle |
AICmuunknown |
Value of Akaike's Information Criterion for the general NNTS axial model with unknown location angle |
BICmuunknown |
Value of Bayesian Information Criterion for the general NNTS axial model with unknown location angle |
gradnormerrormuunknown |
Gradient error after the last iteration for the estimation of the parameters of the general NNTS axial model with unknown location angle |
loglikratioformuknown |
Value of the likelihood ratio test statistic for known location angle |
loglikratioformuknownpvalue |
Value of the asymptotic chi squared p-value of the likelihood ratio test statistic for known location angle |
Juan Jose Fernandez-Duran and Maria Mercedes Gregorio-Dominguez
Fernandez-Duran, J.J. and Gregorio-Dominguez, M.M. (2025). Multimodal distributions for circular axial data. arXiv:2504.04681 [stat.ME] (available at https://arxiv.org/abs/2504.04681)
data(Datab2fisher)
feldsparsangles<-Datab2fisher
feldsparsangles<-feldsparsangles$orientations*(pi/180)
resfeldsparknownangle<-axialnntsmanifoldnewtonestimationgradientstopknownmu(data=feldsparsangles,
muknown=pi/2, M = 2, iter =1000, gradientstop=1e-10)
resfeldsparknownangle
hist(feldsparsangles,breaks=seq(0,pi,pi/7),xlab="Orientations (radians)",freq=FALSE,
ylab="",main="",ylim=c(0,.8),axes=FALSE)
axialnntsplot(resfeldsparknownangle$cestimatesmuunknown[,2],2,add=TRUE)
axialnntsplot(resfeldsparknownangle$cestimatesmuknown[,2],2,add=TRUE,lty=2)
axis(1,at=c(0,pi/2,pi),labels=c("0",expression(pi/2),expression(pi)),las=1)
axis(2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.